==> 0.0.29.tar.gz: lib/model/shipment_status.dart <==
part of trober_sdk.api;

enum ShipmentStatus {
  unassigned,
  inTransit,
  arrived,
  assigned,
  accepted,
  rejected,
  loaded,
  unloaded,
  abandoned
}

class ShipmentStatusTypeTransformer {
  static Map<String, ShipmentStatus> fromJsonMap = {
    "Unassigned": ShipmentStatus.unassigned,
    "InTransit": ShipmentStatus.inTransit,
    "Arrived": ShipmentStatus.arrived,
    "Assigned": ShipmentStatus.assigned,
    "Accepted": ShipmentStatus.accepted,
    "Rejected": ShipmentStatus.rejected,
    "Loaded": ShipmentStatus.loaded,
    "Unloaded": ShipmentStatus.unloaded,
    "Abandoned": ShipmentStatus.abandoned
  };
  static Map<ShipmentStatus, String> toJsonMap = {
    ShipmentStatus.unassigned: "Unassigned",
    ShipmentStatus.inTransit: "InTransit",
    ShipmentStatus.arrived: "Arrived",
    ShipmentStatus.assigned: "Assigned",
    ShipmentStatus.accepted: "Accepted",
    ShipmentStatus.rejected: "Rejected",
    ShipmentStatus.loaded: "Loaded",
    ShipmentStatus.unloaded: "Unloaded",
    ShipmentStatus.abandoned: "Abandoned"
  };

  static ShipmentStatus fromJson(dynamic data) {
    var found = fromJsonMap[data];
    if (found == null) {
      throw ('Unknown enum value to decode: $data');
    }
    return found;
  }

  static dynamic toJson(ShipmentStatus data) {
    return toJsonMap[data];
  }

  static List<ShipmentStatus> listFromJson(List<dynamic> json) {
    return json == null
        ? <ShipmentStatus>[]
        : json.map((value) => fromJson(value)).toList();
  }

  static ShipmentStatus copyWith(ShipmentStatus instance) {
    return instance;
  }

  static Map<String, ShipmentStatus> mapFromJson(Map<String, dynamic> json) {
    final map = <String, ShipmentStatus>{};
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = fromJson(value));
    }
    return map;
  }
}

==> 0.0.42.tar.gz: lib/model/shipment_status.dart <==
part of trober_sdk.api;

enum ShipmentStatus {
  unassigned,
  inTransit,
  arrived,
  assigned,
  accepted,
  rejected,
  loaded,
  delivered
}

class ShipmentStatusTypeTransformer {
  static Map<String, ShipmentStatus> fromJsonMap = {
    "Unassigned": ShipmentStatus.unassigned,
    "InTransit": ShipmentStatus.inTransit,
    "Arrived": ShipmentStatus.arrived,
    "Assigned": ShipmentStatus.assigned,
    "Accepted": ShipmentStatus.accepted,
    "Rejected": ShipmentStatus.rejected,
    "Loaded": ShipmentStatus.loaded,
    "Delivered": ShipmentStatus.delivered
  };
  static Map<ShipmentStatus, String> toJsonMap = {
    ShipmentStatus.unassigned: "Unassigned",
    ShipmentStatus.inTransit: "InTransit",
    ShipmentStatus.arrived: "Arrived",
    ShipmentStatus.assigned: "Assigned",
    ShipmentStatus.accepted: "Accepted",
    ShipmentStatus.rejected: "Rejected",
    ShipmentStatus.loaded: "Loaded",
    ShipmentStatus.delivered: "Delivered"
  };

  static ShipmentStatus fromJson(dynamic data) {
    var found = fromJsonMap[data];
    if (found == null) {
      throw ('Unknown enum value to decode: $data');
    }
    return found;
  }

  static dynamic toJson(ShipmentStatus data) {
    return toJsonMap[data];
  }

  static List<ShipmentStatus> listFromJson(List<dynamic> json) {
    return json == null
        ? <ShipmentStatus>[]
        : json.map((value) => fromJson(value)).toList();
  }

  static ShipmentStatus copyWith(ShipmentStatus instance) {
    return instance;
  }

  static Map<String, ShipmentStatus> mapFromJson(Map<String, dynamic> json) {
    final map = <String, ShipmentStatus>{};
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = fromJson(value));
    }
    return map;
  }
}
